==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-VE/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Acerca de las ubicaciones',
    'about_locations'           => 'Las ubicaciones son utilizadas para hacer seguimiento de la información sobre ubicación de usuarios, activos, y otros ítems',
    'assets_rtd'                => 'Activos', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Activos asignados',
    'id'                        => 'ID',
    'city'                      => 'Ciudad',
    'state'                     => 'Estado',
    'country'                   => 'País',
    'create'                    => 'Crear ubicación',
    'update'                    => 'Actualizar ubicación',
    'print_assigned'            => 'Imprimir los asignados',
    'print_all_assigned'        => 'Imprimir todos los asignados',
    'name'                      => 'Nombre de ubicación',
    'address'                   => 'Dirección',
    'address2'                   => 'Dirección línea 2',
    'zip'                       => 'Código postal',
    'locations'                 => 'Ubicaciones',
    'parent'                    => 'Ubicación padre',
    'currency'                  => 'Divisa de la ubicación',
    'ldap_ou'                   => 'Búsqueda LDAP OU',
    'user_name'                 => 'Usuario',
    'department'                => 'Departamento',
    'location'                  => 'Ubicación',
    'asset_tag'                 => 'Placa del activo',
    'asset_name'                => 'Nombre',
    'asset_category'            => 'Categoría',
    'asset_manufacturer'        => 'Fabricante',
    'asset_model'               => 'Modelo',
    'asset_serial'              => 'Número de serie',
    'asset_location'            => 'Ubicación',
    'asset_checked_out'         => 'Asignado a',
    'asset_expected_checkin'    => 'Fecha esperada de devolución',
    'date'                      => 'Fecha:',
    'phone'                     => 'Teléfono ubicación',
    'signed_by_asset_auditor'   => 'Firmado por (Juego de Acciones):',
    'signed_by_finance_auditor' => 'Firmado por (Monitor de Finanzas):',
    'signed_by_location_manager' => 'Firmado por (Administrador de ubicación):',
    'signed_by'                 => 'Firmado por:',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/es-VE/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Acerca de las ubicaciones',
    'about_locations'           => 'Las ubicaciones se utilizan para hacer un seguimiento de la ubicación de usuarios, activos y otros elementos',
    'assets_rtd'                => 'Activos', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Activos asignados',
    'id'                        => 'ID',
    'city'                      => 'Ciudad',
    'state'                     => 'Estado',
    'country'                   => 'País',
    'create'                    => 'Crear ubicación',
    'update'                    => 'Actualizar ubicación',
    'print_assigned'            => 'Imprimir los asignados',
    'print_all_assigned'        => 'Imprimir todos los asignados',
    'name'                      => 'Nombre de ubicación',
    'address'                   => 'Dirección',
    'address2'                   => 'Dirección línea 2',
    'zip'                       => 'Código postal',
    'locations'                 => 'Ubicaciones',
    'parent'                    => 'Ubicación padre',
    'currency'                  => 'Divisa de la ubicación',
    'ldap_ou'                   => 'Búsqueda LDAP OU',
    'user_name'                 => 'Usuario',
    'department'                => 'Departamento',
    'location'                  => 'Ubicación',
    'asset_tag'                 => 'Placa del activo',
    'asset_name'                => 'Nombre',
    'asset_category'            => 'Categoría',
    'asset_manufacturer'        => 'Fabricante',
    'asset_model'               => 'Modelo',
    'asset_serial'              => 'Número de serie',
    'asset_location'            => 'Ubicación',
    'asset_checked_out'         => 'Asignado a',
    'asset_expected_checkin'    => 'Fecha esperada de devolución',
    'date'                      => 'Fecha:',
    'phone'                     => 'Teléfono ubicación',
    'signed_by_asset_auditor'   => 'Firmado por (Auditor de Activos):',
    'signed_by_finance_auditor' => 'Firmado por (Auditor de Finanzas):',
    'signed_by_location_manager' => 'Firmado por (Supervisor de la ubicación):',
    'signed_by'                 => 'Firmado por:',
];
